/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.controller.helix.core.rebalance;

import org.apache.commons.configuration.Configuration;
import org.apache.helix.model.IdealState;
import org.apache.pinot.common.config.TableConfig;
import org.apache.pinot.common.exception.InvalidConfigException;
import org.apache.pinot.common.partition.PartitionAssignment;


/**
 * Interface for rebalance segment strategies
 */
public interface RebalanceSegmentStrategy {

  /**
   * Rebalances and writes partition assignments involved in the rebalance of the table
   * @param idealState old ideal state
   * @param tableConfig table config of table tor rebalance
   * @param rebalanceUserConfig custom user configs for specific rebalance strategies
   * @return rebalanced partition assignments
   */
  PartitionAssignment rebalancePartitionAssignment(IdealState idealState, TableConfig tableConfig,
      Configuration rebalanceUserConfig)
      throws InvalidConfigException;

  /**
   * Rebalances segments and returns the rebalanced ideal state.
   * @param idealState old ideal state
   * @param tableConfig table config of table tor rebalance
   * @param rebalanceUserConfig custom user configs for specific rebalance strategies
   * @param newPartitionAssignment new rebalaned partition assignments as part of the resource rebalance
   * @return rebalanced ideal state
   */
  IdealState getRebalancedIdealState(IdealState idealState, TableConfig tableConfig, Configuration rebalanceUserConfig,
      PartitionAssignment newPartitionAssignment)
      throws InvalidConfigException;
}
