/**
 * Copyright (C) 2014-2018 LinkedIn Corp. (pinot-core@linkedin.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.pinot.thirdeye.hadoop.topk;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import org.apache.pinot.thirdeye.hadoop.config.DimensionType;

/**
 * Wrapper for the key generated by mapper in TopKPhase
 */
public class TopKPhaseMapOutputKey {

  String dimensionName;
  Object dimensionValue;
  DimensionType dimensionType;

  public TopKPhaseMapOutputKey(String dimensionName, Object dimensionValue, DimensionType dimensionType) {
    this.dimensionName = dimensionName;
    this.dimensionValue = dimensionValue;
    this.dimensionType = dimensionType;
  }

  public String getDimensionName() {
    return dimensionName;
  }

  public Object getDimensionValue() {
    return dimensionValue;
  }

  public DimensionType getDimensionType() {
    return dimensionType;
  }

  /**
   * Converts a TopKPhaseMapOutputKey to a bytes buffer
   * @return
   * @throws IOException
   */
  public byte[] toBytes() throws IOException {

    ByteArrayOutputStream baos = new ByteArrayOutputStream();
    DataOutputStream dos = new DataOutputStream(baos);
    byte[] bytes;
    // dimension name
    bytes = dimensionName.getBytes();
    dos.writeInt(bytes.length);
    dos.write(bytes);

    // dimension type
    bytes = dimensionType.toString().getBytes();
    dos.writeInt(bytes.length);
    dos.write(bytes);

    // dimension value
    DimensionType.writeDimensionValueToOutputStream(dos, dimensionValue, dimensionType);
    baos.close();
    dos.close();
    return baos.toByteArray();
  }

  /**
   * Constructs a TopKPhaseMapOutputKey from a bytes buffer
   * @param buffer
   * @return
   * @throws IOException
   */
  public static TopKPhaseMapOutputKey fromBytes(byte[] buffer) throws IOException {
    DataInputStream dis = new DataInputStream(new ByteArrayInputStream(buffer));
    int length;
    byte[] bytes;

    // dimension name
    length = dis.readInt();
    bytes = new byte[length];
    dis.read(bytes);
    String dimensionName = new String(bytes);

    // dimension type
    length = dis.readInt();
    bytes = new byte[length];
    dis.read(bytes);
    String dimensionTypeString = new String(bytes);
    DimensionType dimensionType = DimensionType.valueOf(dimensionTypeString);

    // dimension value
    Object dimensionValue = DimensionType.readDimensionValueFromDataInputStream(dis, dimensionType);

    TopKPhaseMapOutputKey wrapper;
    wrapper = new TopKPhaseMapOutputKey(dimensionName, dimensionValue, dimensionType);
    return wrapper;
  }

}
